docstripy.google package
========================

Submodules
----------

docstripy.google.build\_doc module
----------------------------------

.. automodule:: docstripy.google.build_doc
   :members:
   :undoc-members:
   :show-inheritance:

docstripy.google.parse\_doc module
----------------------------------

.. automodule:: docstripy.google.parse_doc
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: docstripy.google
   :members:
   :undoc-members:
   :show-inheritance:
